@@ -39,7 +39,7 @@ use vars qw[@ISA $VERSION];
             CPANPLUS::Internals::Report
         ];
 
-$VERSION = "0.9152";
+$VERSION = "0.9156";
 
 =pod
 
@@ -426,7 +426,7 @@ sub _add_to_includepath {
 
     ### only add if it's not added yet
     for my $lib (@$dirs) {
-        push @INC, $lib unless grep { $_ eq $lib } @INC;
+        unshift @INC, $lib unless grep { $_ eq $lib } @INC;
         #
         ### it will be complaining if $ENV{PERL5LIB] is not defined (yet).
         local $^W;
